# Jubilant

```{toctree}
:maxdepth: 2
:hidden: true

reference/index
```

Jubilant is a Python library that wraps the [Juju](https://juju.is/) CLI for use in charm integration tests. It provides methods that map 1:1 to Juju CLI commands, but with a type-annotated, Pythonic interface.

Jubilant is in very early stages of development. For more information, see the [Jubilant repository](https://github.com/canonical/jubilant).